/* Copyright (C) 1989 Aladdin Enterprises.  All rights reserved.
   Distributed by Free Software Foundation, Inc.

This file is part of Ghostscript.

Ghostscript is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY.  No author or distributor accepts responsibility
to anyone for the consequences of using it or for whether it serves any
particular purpose or works at all, unless he says so in writing.  Refer
to the Ghostscript General Public License for full details.

Everyone is granted permission to copy, modify and redistribute
Ghostscript, but only under the conditions described in the Ghostscript
General Public License.  A copy of this license is supposed to have been
given to you along with Ghostscript so you can know your rights and
responsibilities.  It should be in a file named COPYING.  Among other
things, the copyright notice and this notice must be preserved on all
copies.  */

/* dict.h */
/* Interfaces for GhostScript dictionary package */

/* Create a dictionary */
extern int dict_create(P2(uint, ref *));

/* Look up in a dictionary.  Store a pointer to the value slot */
/* where found, or to the (value) slot for inserting. */
/* Return 1 if found, 0 if not and there is room for a new entry, */
/* or e_dictfull if the dictionary is full and the key is missing. */
/* The caller is responsible for ensuring key is not a null. */
extern int dict_find(P3(ref * /*dict*/, ref * /*key*/, ref ** /*ppvalue*/));

/* Enter a key-value pair in a dictionary. */
/* Return 0 or e_dictfull. */
extern int dict_put(P3(ref * /*dict*/, ref * /*key*/, ref * /*pvalue*/));

/* Look up a key on the dictionary stack. */
/* Return a pointer to its value, or 0 if not found. */
extern ref *dict_search(P2(ref * /*key*/, ref * /*dsp*/));

/* Return the number of elements in a dictionary. */
extern uint dict_length(P1(ref *));

/* Return the capacity of a dictionary. */
extern uint dict_maxlength(P1(ref *));

/* Copy one dictionary into another. */
/* Return 0 or e_dictfull. */
extern int dict_copy(P2(ref * /*from*/, ref * /*to*/));

/* Prepare to enumerate a dictionary. */
/* Return an integer suitable for the first call to dict_next. */
extern int dict_first(P1(ref *));

/* Enumerate the next element of a dictionary. */
/* index is initially the result of a call on dict_first. */
/* Either store a key and value at eltp[0] and eltp[1] */
/* and return an updated index, or return -1 */
/* to signal that there are no more elements in the dictionary. */
extern int dict_next(P3(ref *, int /*index*/, ref * /*eltp*/));
